==> lxqt-config-0.9.0.tar.xz: lxqt-config-0.9.0/liblxqt-config-cursor/translations/lxqt-config-cursor_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../ui/selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuração Do Tema Do Mouse</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Selecione o tema do cursor que você deseja usar (pairar visualização para testar o cursor). &lt;b&gt;A sessão LXQt precisa reiniciar após esta mudança&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar Novo Tema...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">&amp;Definir Tema</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Remover Tema</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Erro XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Você não pode remover o tema ativo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../ui/warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/liblxqt-config-cursor/translations/lxqt-config-cursor_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuração do Tema do Mouse do LXQT</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Selecione o tema do cursor que você deseja usar (coloque o cursor em cima para testar). &lt;b&gt;Precisa reiniciar a sessão LXQt  após esta mudança&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar Novo Tema...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Remover Tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>Erro XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Você não pode remover o tema ativo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>O LXQt não encontrou nenhum tema de cursor. O tema padrão do cursor X11 será usado no lugar. LXQt procurou nos seguintes diretórios:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Exibir...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>
